@@ -1,7 +1,7 @@
 package Code::Includable::Tree::NodeMethods;
 
-our $DATE = '2016-03-23'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-03-26'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 # we must contain no other functions
 
@@ -18,10 +18,18 @@ sub _children_as_list {
     @c;
 }
 
+sub _descendants {
+    my ($self, $res) = @_;
+    my @c = _children_as_list($self);
+    push @$res, @c;
+    for (@c) { _descendants($_, $res) }
+}
+
 sub descendants {
     my $self = shift;
-    my @c = _children_as_list($self);
-    (@c, map { descendants($_) } @c);
+    my $res = [];
+    _descendants($self, $res);
+    @$res;
 }
 
 sub walk {
@@ -191,7 +199,7 @@ Code::Includable::Tree::NodeMethods - Tree node routines
 
 =head1 VERSION
 
-This document describes version 0.06 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-23.
+This document describes version 0.07 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-26.
 
 =head1 DESCRIPTION
 
