@@ -1,7 +1,7 @@
 package Role::TinyCommons::Tree::Node;
 
-our $DATE = '2016-03-23'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-03-26'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use Role::Tiny;
 
@@ -23,7 +23,7 @@ Role::TinyCommons::Tree::Node - Role for a tree node object
 
 =head1 VERSION
 
-This document describes version 0.06 of Role::TinyCommons::Tree::Node (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-23.
+This document describes version 0.07 of Role::TinyCommons::Tree::Node (from Perl distribution Role-TinyCommons-Tree), released on 2016-03-26.
 
 =head1 DESCRIPTION
 
@@ -34,8 +34,18 @@ L<Role::TinyCommons::Tree::NodeMethods>.
 
 =head2 parent => obj
 
+This must be an accessor, i.e. it must be able to set parent attribute using:
+
+ $obj->parent($parent)
+
 =head2 children => list of obj|arrayref of obj
 
+This must be an accessor, i.e. it must be able to set children attribute using:
+
+ $obj->children([$child1, ...])
+
+But for flexibility, it is allowed to return arrayref or list.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Role-TinyCommons-Tree>.
